package
Version:
v0.0.0-...-27b3b18
Opens a new window with list of versions in this module.
Published: May 20, 2025
License: AGPL-3.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Alerts struct {
Dir string
}
Alerts represents alert cfg paths.
Cfg represents cfg paths.
Install represents install paths.
Plat represents plat cfg paths.
Sigs represents sig paths.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.