Discover Packages
github.com/worthwhilefoo/malwatch
pkg
db
orm
hit
package
Version:
v0.0.0-...-27b3b18
Opens a new window with list of versions in this module.
Published: May 20, 2025
License: AGPL-3.0
Opens a new window with license information.
Imports: 10
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
DelPath deletes path hits.
DelTarget deletes target hits. Entire key is removed.
type History struct {
Target string `json:"target"`
Paths Paths `json:"paths"`
}
History represents target hit history.
SelectAll returns all hits.
ToSlice returns string slices from given history.
type Meta struct {
Time time .Time `json:"time"`
Rules []string `json:"rules"`
Status string `json:"status"`
Attr *fsys .Attr `json:"attr"`
Acts []string `json:"actions"`
}
Meta represents hit meta.
NewMeta returns new hit meta.
SelectLast returns a path's most recent hit.
Restore restores a quarantined hit.
ToSlice returns a string slice from given meta and path.
Paths represents path:hits.
SelectTarget returns a target's hits.
ToSlice returns string slices from given paths.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.